======================================
neutcurve
======================================

.. image:: https://img.shields.io/pypi/v/neutcurve.svg
        :target: https://pypi.python.org/pypi/neutcurve
.. image:: https://github.com/jbloomlab/neutcurve/actions/workflows/test.yml/badge.svg
        :target: https://github.com/jbloomlab/neutcurve/actions/workflows/test.yml
.. image:: https://img.shields.io/badge/code%20style-black-000000.svg
        :target: https://github.com/psf/black
.. image:: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v2.json
        :target: https://github.com/astral-sh/ruff

``neutcurve`` is a Python package written by the `Bloom lab <https://research.fhcrc.org/bloom/en.html>`_ for plotting neutralization curves.

See the `neutcurve documentation <https://jbloomlab.github.io/neutcurve/>`_ for details on how to install and use ``neutcurve``.

Please cite `Loes et al (2024) <https://doi.org/10.1101/2024.03.08.584176>`_ if you use ``neutcurve`` in your scientific study.
